.. _installation:

Installation
=====================================

Using pip (Python 3.7+)
-----------------------
* Installation

.. code-block:: bash

    pip install hckr

* Upgrading

.. code-block:: bash

    pip install --upgrade hckr

Using HomeBrew (MacOS)
----------------------
* Installation

.. code-block:: bash

   brew tap hckr-cli/tap
   brew install hckr

* Upgrading

.. code-block:: bash

   brew update --force
   brew upgrade hckr

.. toctree::
   :hidden:

   shell_completion
